"use strict";

/*! SimpleConnect Libraries v1.0.0 awri.ch | Robert Schweng */
/**
 *  SimpleConnect Libraries v1.0.0
 *  
 *   SimpleConnect(host="http://localhost",async=false)
 *   setCSRFToken(token); 
 * 
 *   request(method="GET",path="",data=null,content_type="application/json",async=true);
 *   returns Promise or SimpleConnectError if response Status is not between 200 and 300;
 *    
 *    NOTES:
 *    - Die Bluebird Library für ES5 Promises wird benötigt 
 *    - keine Arrow => Funktionen nutzen (ES5)!
 *    - Drupal 7 Services ab 3.4 benötigt für jeden POST, PUT und DELETE Request ein neues CSRFToken
 **/
 
 
/*
SIMPLECONNECT SERVICE ENDPOINTS
GET rest/simpleconnect/token
POST rest/simpleconnect/connect
POST rest/simpleconnect/login
POST rest/simpleconnect/logout
POST rest/simpleconnect/register
*/

/*
folgende Funktionen liefern Bluebird Promises zurück 
token()
connect()
login(username,password)
logout()
register(username,password,email)
request(method,path,data,content-type)
*/


var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }


var SimpleConnect = function () {

    function SimpleConnect(host,async) {
        _classCallCheck(this, SimpleConnect);
        if(typeof async == 'undefined')this._async=true;
        else this._async=async;
        if(typeof host == 'undefined')this.host='http://localhost';
        else this.host=host;
        console.log('SimpleConnect constructed:' + this.host+' async='+this._async);
    }

    _createClass(SimpleConnect, [{
        key: "token",
        value: function token() {
            return this.request('GET',"rest/simpleconnect/token");

            } //Func
  
        }, { //Func

        key: "connect",
        value: function connect() {     

            return this.request('POST',"rest/simpleconnect/connect?_format=json");
            }
         }, { //Func

        key: "login",
        value: function login(username,password) {
            var postData = {        
                username: username,
                password: password
              }   
              return this.request("POST","rest/simpleconnect/login?_format=json",postData);
            }
    }, { //Func
        key: "logout",
        value: function logout() {
            return this.request("POST","rest/simpleconnect/logout?_format=json");

        }//func

    }, { //Func
        key: "register",
        value: function register(username,password,mail)  {
            var postData = {        
                email: mail ,
                username: username,
                password:password 
              }   
              return this.request("POST","rest/simpleconnect/register?_format=json",postData);
        }//Func

    }, { //Func
        key: "setCSRFToken",
        value: function setCSRFToken(token)  {
            this._token=token;
        }//Func

    }, { //Func
        key: "request",        
        value: function request(method,path,data,content_type,async) {
            var h=this.host;
            var a=this._async;
            var t=this._token;
            return new Promise(function (resolve, reject) {
                var xmlhttp = new XMLHttpRequest();        
                if(method == 'undefined' || method == "")method='GET';
             //   if(typeof async !== undefined)a=async;
                if(typeof path == 'undefined')path='';
                if(typeof content_type == 'undefined' || content_type == "")content_type='application/json';
                console.log(method+' '+path+' ('+content_type+') async='+a);
                xmlhttp.withCredentials = true;
                xmlhttp.crossDomain = true;
                xmlhttp.open(method, h +'/'+ path,a);
                xmlhttp.setRequestHeader("Content-Type", content_type);
                xmlhttp.setRequestHeader("X-CSRF-Token", t);             
                xmlhttp.onreadystatechange = function () {
                    if (xmlhttp.readyState == 4) {              
                        if((xmlhttp.status >= 200&&xmlhttp.status<=300)){
                            var obj = xmlhttp.responseText;                                                                                                                                                          
                            return  resolve(obj);
                        }                                                           
                         else return reject(Error(xmlhttp.status+' '+xmlhttp.responseText));            
                    };
                };  
                xmlhttp.send(JSON.stringify(data));
            }).catch(function(err){
                throw  new SimpleConnectError(err.name,err.message);
            });
        }//Func

    }]);

    return SimpleConnect;
}();


function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var SimpleConnectError = function (Error) {
  
    _inherits(SimpleConnectError, Error);

    function SimpleConnectError(message,name) {
        _classCallCheck(this, SimpleConnectError);

        var _this = _possibleConstructorReturn(this, (SimpleConnectError.__proto__ || Object.getPrototypeOf(SimpleConnectError)).call(this, message));
        _this.message = message;
        _this.name = name;
        return Error(message+' '+name);
    }

    return SimpleConnectError;
}(Error);
