'use strict';
/**
 * SimpleConnect Client 1.0.0
 * Robert Schweng
 * awri.ch 2020   
 **/

 
/*
SIMPLECONNECT SERVICE ENDPOINTS
GET rest/simpleconnect/token
POST rest/simpleconnect/connect
POST rest/simpleconnect/login
POST rest/simpleconnect/logout
POST rest/simpleconnect/register
*/

/*
folgende Funktionen liefern Bluebird Promises zurück 
token()
connect()
login(username,password)
logout()
register(username,password,email)
request(method,path,data,content-type)
*/


class SimpleConnect{

    constructor(host,async=true){    
        this.host=host;
        this._async=async;
        this._token=null;
        console.log("AWRI constructed: "+ this.host+' sync='+this._async);        
    }
        
    setCSRFToken(token) {        
            this._token=token;
    }

    token() {        
        return this.request('GET', "rest/simpleconnect/token");
    }
        
    connect() {               
        return this.request('POST', "rest/simpleconnect/connect");
    }
        
    login(username,password) {                
        let postData = {        
            "username": username,
            "password": password
            }   
        return this.request('POST', "rest/simpleconnect/login?_format=json", postData);             
    }

    logout() {          
        return this.request('POST', "rest/simpleconnect/logout?_format=json");  
    }            

    register(username, password, email) {
        let request = {            
            email: email,
            username: username,
            password:password
            }
        return this.request('POST', "rest/simpleconnect/register?_format=json",request);              
                
    }
 
    async request(method="GET",path="",data,content_type="application/json",async=true) {
        let h=this.host;
        let t=this._token;
        return new Promise(function (resolve, reject){
            var xmlhttp = new XMLHttpRequest();
                console.log(method+' '+h+' '+path+' ('+content_type+')');
                xmlhttp.withCredentials = true;
                xmlhttp.crossDomain = true;
                xmlhttp.open(method, h +'/'+ path,async);
                xmlhttp.setRequestHeader("Content-Type", content_type);
                xmlhttp.setRequestHeader("X-CSRF-Token", t);             
                xmlhttp.onreadystatechange = function () {
                if (xmlhttp.readyState == 4) {              
                    if((xmlhttp.status >= 200&&xmlhttp.status<=300)){
                        let obj = xmlhttp.responseText;                                                                                                                                                          
                        return  resolve(obj);
                            }                                                           
                        else  reject(new SimpleConnectError(xmlhttp.status,"request:"+path));            
                    };
                };  
                xmlhttp.send(JSON.stringify(data));
        }).catch(function(err){
            throw err;
        });
    }
   
}//Class SimpleConnect


class SimpleConnectError extends Error{
    constructor(msg,name){
    super(msg,name);
    this.message=msg;
    this.name=name   
    }
}//Class SimpleConnectError
